==> pointpos_api-0.0.16.tar.gz: doc/PurchaseOrderApi.md <==
# pointpos_api.api.PurchaseOrderApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createPurchaseorder**](PurchaseOrderApi.md#createPurchaseorder) | **Post** /purchase-order | Create Purchaseorder
[**deletePurchaseorderByID**](PurchaseOrderApi.md#deletePurchaseorderByID) | **Delete** /purchase-order/:outletId | Delete Purchaseorder By ID
[**findPurchaseorder**](PurchaseOrderApi.md#findPurchaseorder) | **Get** /purchase-order | Get Purchaseorder List
[**getPurchaseorderByID**](PurchaseOrderApi.md#getPurchaseorderByID) | **Get** /purchase-order/:outletId | Get Purchaseorder By ID
[**updatePurchaseorderByID**](PurchaseOrderApi.md#updatePurchaseorderByID) | **Put** /purchase-order/:outletId | Update Purchaseorder By ID


# **createPurchaseorder**
> PurchaseOrder createPurchaseorder(authorization, xAPIKey, body, xPin)

Create Purchaseorder

Create Purchaseorder

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = new PurchaseOrder(); // PurchaseOrder | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.createPurchaseorder(authorization, xAPIKey, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->createPurchaseorder: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**PurchaseOrder**](PurchaseOrder.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**PurchaseOrder**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deletePurchaseorderByID**
> deletePurchaseorderByID(authorization, xAPIKey, outletId, xPin)

Delete Purchaseorder By ID

Delete Purchaseorder By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var outletId = outletId_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    api_instance.deletePurchaseorderByID(authorization, xAPIKey, outletId, xPin);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->deletePurchaseorderByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **outletId** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findPurchaseorder**
> List<PurchaseOrder> findPurchaseorder(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter)

Get Purchaseorder List

Get Purchaseorder  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var xPin = xPin_example; // String | PIN Number
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"outletId\"   - \"supplierId\"   - \"note\"   - \"ingredients\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findPurchaseorder(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->findPurchaseorder: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;outletId\&quot;   - \&quot;supplierId\&quot;   - \&quot;note\&quot;   - \&quot;ingredients\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to const []]

### Return type

[**List<PurchaseOrder>**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPurchaseorderByID**
> PurchaseOrder getPurchaseorderByID(authorization, xAPIKey, outletId, xPin)

Get Purchaseorder By ID

Get Purchaseorder By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var outletId = outletId_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.getPurchaseorderByID(authorization, xAPIKey, outletId, xPin);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->getPurchaseorderByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **outletId** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**PurchaseOrder**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updatePurchaseorderByID**
> PurchaseOrder updatePurchaseorderByID(authorization, xAPIKey, outletId, body, xPin)

Update Purchaseorder By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var outletId = outletId_example; // String | 
var body = new PurchaseOrder(); // PurchaseOrder | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.updatePurchaseorderByID(authorization, xAPIKey, outletId, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->updatePurchaseorderByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **outletId** | **String**|  | [default to null]
 **body** | [**PurchaseOrder**](PurchaseOrder.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**PurchaseOrder**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> pointpos_api-0.2.0.tar.gz: doc/PurchaseOrderApi.md <==
# pointpos_api.api.PurchaseOrderApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createPurchaseorder**](PurchaseOrderApi.md#createPurchaseorder) | **Post** /purchase-order | Create Purchaseorder
[**deletePurchaseorderByID**](PurchaseOrderApi.md#deletePurchaseorderByID) | **Delete** /purchase-order/:outletId | Delete Purchaseorder By ID
[**findPurchaseorder**](PurchaseOrderApi.md#findPurchaseorder) | **Get** /purchase-order | Get Purchaseorder List
[**getPurchaseorderByID**](PurchaseOrderApi.md#getPurchaseorderByID) | **Get** /purchase-order/:outletId | Get Purchaseorder By ID
[**updatePurchaseorderByID**](PurchaseOrderApi.md#updatePurchaseorderByID) | **Put** /purchase-order/:outletId | Update Purchaseorder By ID


# **createPurchaseorder**
> PurchaseOrder createPurchaseorder(authorization, xAPIKey, body, xPin)

Create Purchaseorder

Create Purchaseorder

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = new PurchaseOrder(); // PurchaseOrder | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.createPurchaseorder(authorization, xAPIKey, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->createPurchaseorder: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**PurchaseOrder**](PurchaseOrder.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**PurchaseOrder**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deletePurchaseorderByID**
> deletePurchaseorderByID(authorization, xAPIKey, outletId, xPin)

Delete Purchaseorder By ID

Delete Purchaseorder By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var outletId = outletId_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    api_instance.deletePurchaseorderByID(authorization, xAPIKey, outletId, xPin);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->deletePurchaseorderByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **outletId** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findPurchaseorder**
> List<PurchaseOrder> findPurchaseorder(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter, withDeleted)

Get Purchaseorder List

Get Purchaseorder  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var xPin = xPin_example; // String | PIN Number
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'createdAt|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"outletId\"   - \"supplierId\"   - \"note\"   - \"ingredients\"   - \"createdAt\"   - \"createdBy\"   - \"updatedAt\"   - \"updatedBy\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 
var withDeleted = true; // bool | Return with deleted resource

try { 
    var result = api_instance.findPurchaseorder(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter, withDeleted);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->findPurchaseorder: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;createdAt|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;outletId\&quot;   - \&quot;supplierId\&quot;   - \&quot;note\&quot;   - \&quot;ingredients\&quot;   - \&quot;createdAt\&quot;   - \&quot;createdBy\&quot;   - \&quot;updatedAt\&quot;   - \&quot;updatedBy\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to const []]
 **withDeleted** | **bool**| Return with deleted resource | [optional] [default to false]

### Return type

[**List<PurchaseOrder>**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPurchaseorderByID**
> PurchaseOrder getPurchaseorderByID(authorization, xAPIKey, outletId, xPin)

Get Purchaseorder By ID

Get Purchaseorder By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var outletId = outletId_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.getPurchaseorderByID(authorization, xAPIKey, outletId, xPin);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->getPurchaseorderByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **outletId** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**PurchaseOrder**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updatePurchaseorderByID**
> PurchaseOrder updatePurchaseorderByID(authorization, xAPIKey, outletId, body, xPin)

Update Purchaseorder By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new PurchaseOrderApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var outletId = outletId_example; // String | 
var body = new PurchaseOrder(); // PurchaseOrder | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.updatePurchaseorderByID(authorization, xAPIKey, outletId, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling PurchaseOrderApi->updatePurchaseorderByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **outletId** | **String**|  | [default to null]
 **body** | [**PurchaseOrder**](PurchaseOrder.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**PurchaseOrder**](PurchaseOrder.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
